coost

package module
v0.4.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 29, 2025 License: AGPL-3.0 Imports: 8 Imported by: 7

README

coost

coost is a cookie storage module for reading, writing and importing cookie jars.

Importing cookies from an existing browser session

To import browser session cookies (instructions for Google Chrome, should work for any browser):

  1. Launch a browser, then open Developer Tools: a. Select "Customize and control Google Chrome" menu item, visually represented as three vertical dots; b. Select "More Tools" menu item, then "Developer Tools"; c. Select "Network" tab in the Developer Tools.
  2. Navigate to the desired website (e.g. example.com);
  3. Select that navigation request in the Network tab of Developer Tools;
  4. Select "Headers" tab in the request preview section;
  5. Navigate to the Request Headers section (not Response Headers!);
  6. Find cookie: header and Copy value for that header (or select the value and copy);
  7. In application that uses coost - run import-cookies command with a cookie header value: import-cookies "key1=value1; key2=value2;"

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Import added in v0.4.0

func Import(cookieStr string, u *url.URL, path string) error

func Read added in v0.4.0

func Read(u *url.URL, path string) (http.CookieJar, error)

func Write added in v0.4.0

func Write(jar http.CookieJar, u *url.URL, path string) error

Types

This section is empty.

Jump to